XdgFileChooserPortalSaveFilesResult class

Result of a request asking for a folder as a location to save one or more files.

Constructors

XdgFileChooserPortalSaveFilesResult({required List<String> uris, Map<String, String> choices = const {}})

Properties

choices Map<String, String>
Result of the choices taken in the chooser.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uris List<String>
The URIs selected in the file chooser.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited