XdgNotificationActionInvokedEvent class

An event that is emitted when a notification action is invoked.

Constructors

XdgNotificationActionInvokedEvent(String id, String action)
const

Properties

action String
Name of the action that was invoked.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Id of the notification that this action was invoked on.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override