XdgTrashPortal class

Portal for trashing files.

Constructors

XdgTrashPortal(DBusRemoteObject _object)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getVersion() Future<int>
Get the version of this portal.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
trashFile(File file) Future<void>
Send a file to the trashcan.

Operators

operator ==(Object other) bool
The equality operator.
inherited